@@ -72,7 +72,6 @@ class ColorVisuals(Visuals):
         try:
             if face_colors is not None:
                 self.face_colors = face_colors
-
             if vertex_colors is not None:
                 self.vertex_colors = vertex_colors
         except ValueError:
@@ -118,15 +117,20 @@ class ColorVisuals(Visuals):
         mode : str or None
           One of ('face', 'vertex', None)
         """
-        self._verify_crc()
-        if 'vertex_colors' in self._data:
-            mode = 'vertex'
-        elif 'face_colors' in self._data:
-            mode = 'face'
-        else:
-            mode = None
+        # if nothing is stored anywhere it's a safe bet mode is None
+        if not (len(self._cache.cache) > 0 or len(self._data.data) > 0):
+            return None
 
-        return mode
+        # do bookkeeping
+        self._verify_crc()
+
+        # check modes in data
+        if 'vertex_colors' in self._data:
+            return 'vertex'
+        elif 'face_colors' in self._data:
+            return 'face'
+
+        return None
 
     def crc(self):
         """
@@ -150,6 +154,7 @@ class ColorVisuals(Visuals):
         """
         Return a copy of the current ColorVisuals object.
 
+
         Returns
         ----------
         copied : ColorVisuals
@@ -408,11 +413,17 @@ class ColorVisuals(Visuals):
         ----------
         visual: ColorVisuals object containing a subset of faces.
         """
+        kwargs = {}
         if self.defined:
-            result = ColorVisuals(
-                face_colors=self.face_colors[face_index])
-        else:
-            result = ColorVisuals()
+            if self.face_colors is not None:
+                kwargs.update(face_colors=self.face_colors[face_index])
+
+            if self.vertex_colors is not None:
+                indices = np.unique(self.mesh.faces[face_index].flatten())
+                vertex_colors = self.vertex_colors[indices]
+                kwargs.update(vertex_colors=vertex_colors)
+
+        result = ColorVisuals(**kwargs)
 
         return result
 
@@ -566,7 +577,7 @@ def to_rgba(colors, dtype=np.uint8):
     colors : (n, 4) list of RGBA colors
              (4,)  single RGBA color
     """
-    if colors is None or not util.is_sequence(colors):
+    if colors is None:
         return DEFAULT_COLOR
 
     # colors as numpy array
